Cheshire3 Objects: GroupTransformer

|  | ## Cheshire3 Objects: Group Transformer

Description

Sometimes a single record may contain multiple items within it, for example a METS document that has references to 20 different images, and you need to extract these components individually. A GroupTransformer will take a Record and turn it into a DocumentGroup with multiple Documents in it. This can also be used for extracting components for indexing, for example pages from a TEI record.

Implementations

- groupTransformer.XPathGroupTransformer
  Extract each occurence of the XPath and treat it as a new document.

API

Function | Parameters | Returns | Description
--- | --- | --- | ---
__init__ | config, parent |  |
process_record | session, record | DocumentGroup | Return a documentGroup after some transformation of the record